@@ -115,7 +115,8 @@ public:
     void dialog_preferences();
     void preferences_import();
     void preferences_export();
-    void command_selnode();
+    void command_selnode() { command_selnode_str(Glib::ustring{}); }
+    void command_selnode_str(const Glib::ustring& entryStr);
     void command_palette();
 
 private:
@@ -334,6 +335,8 @@ public:
     void apply_tag_strikethrough();
     void apply_tag_indent();
     void reduce_tag_indent();
+    void headers_toc_expand();
+    void headers_toc_collapse();
     void apply_tag_h1() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H1); }
     void apply_tag_h2() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H2); }
     void apply_tag_h3() { _apply_tag_hN(CtConst::TAG_PROP_VAL_H3); }
@@ -401,6 +404,7 @@ public:
     void text_selection_upper_case();
     void text_selection_toggle_case();
     void toggle_ena_dis_spellcheck();
+    void toggle_ena_dis_vim_mode();
     void cut_as_plain_text();
     void copy_as_plain_text();
     void paste_as_plain_text();
